@@ -113,7 +113,7 @@ def get_updated_version_requirement(
     package_identifier: str
     version_specifier: str
     package_identifier, version_specifier = re.match(
-        r'^\s*([^\s~<>=]*)?\s*([~<>=].*?)\s*$',
+        r'^\s*([^\s~<>=]*)?\s*([~<>=].*?)?\s*$',
         version_specifiers.pop(0)
     ).groups()
     if version_specifier:
